/*
 * @(#)SFtpMdownloadExample.java
 *
 * Copyright (c) JSCAPE LLC.
 *
 * This software is the confidential and proprietary information of
 * JSCAPE. ("Confidential Information").  You shall not disclose such
 * Confidential Information and shall use it only in accordance with
 * the terms of the license agreement you entered into with JSCAPE.
 */

import com.jscape.inet.sftp.*;
import com.jscape.inet.sftp.events.*;
import com.jscape.inet.ssh.util.SshParameters;
import java.io.*;
import java.util.Enumeration;

public class SFtpMdownloadExample extends SftpAdapter {
    private String ftpHostname;
    private String ftpUsername;
    private String ftpPassword;
    private String filter;
    
    // perform multiple file download
    public void doDownload(String ftpHostname, String ftpUsername, String ftpPassword, String filter) throws SftpException {
    		
		// create new SshParameters instance
		SshParameters params = new SshParameters(ftpHostname,ftpUsername,ftpPassword);    		
		    	
		// create new Sftp instance
		Sftp ftp = new Sftp(params);
        
        //capture SFTP related events
        ftp.addSftpListener(this);
        
        // establish connection
        ftp.connect();        
        
        // download files matching filter
        ftp.mdownload(filter);
        
        // disconnect
        ftp.disconnect();
    }    
    
    
    // captures download event
    public void download(SftpDownloadEvent evt) {
        System.out.println("Downloaded file: " + evt.getFilename());
    }
    
    // captures connect event
    public void connected(SftpConnectedEvent evt) {
        System.out.println("Connected to server: " + evt.getHostname());
    }
    
    // captures disconnect event
    public void disconnected(SftpDisconnectedEvent evt) {
        System.out.println("Disconnected from server: " + evt.getHostname());
    }
    
    
    public static void main(String[] args) {
    	String sshHostname;
    	String sshUsername;
    	String sshPassword;
        String filter;
        try {
            BufferedReader reader = new BufferedReader(new InputStreamReader(System.in));
            System.out.print("Enter SSH hostname (e.g. ftp.myserver.com): ");
            sshHostname = reader.readLine();
            System.out.print("Enter SSH username (e.g. jsmith): ");
            sshUsername = reader.readLine();
            System.out.print("Enter SSH password (e.g. secret): ");
            sshPassword = reader.readLine();
            System.out.print("Enter download filter (e.g. .*\\.txt): ");
            filter = reader.readLine().trim();
            
            
            SFtpMdownloadExample example = new SFtpMdownloadExample();            
            
            // do download
            example.doDownload(sshHostname, sshUsername, sshPassword, filter);
        }
        catch(Exception e) {
            e.printStackTrace();
        }
    }
}
